@@ -11,7 +11,7 @@ def default_cache_func(
         redis_model,
         cache_conf,
 ):
-    redis_dicts = redis_root.get(redis_model, return_dict=True)
+    redis_dicts = redis_root.get(django_model, return_dict=True)
     cache_to_django(
         redis_root,
         django_model,
@@ -25,9 +25,17 @@ def default_cache_func(
     )
 
 
-def cache_to_django(django_model, redis_dicts, redis_root):
+def cache_to_django(
+        redis_root,
+        django_model,
+        redis_dicts,
+):
 
-    async def run_cache_to_django(django_model, redis_dicts, redis_root):
+    async def run_cache_to_django(
+            redis_root,
+            django_model,
+            redis_dicts,
+    ):
         async_chunk_size = redis_root.async_db_requests_limit
         async_tasks = []
         completed = 0
@@ -47,7 +55,11 @@ def cache_to_django(django_model, redis_dicts, redis_root):
                 print(f'{datetime.datetime.now()} - Written {completed} {django_model.__name__} instances from cache to django')
 
     loop = asyncio.get_event_loop()
-    loop.run_until_complete(run_cache_to_django(django_model, redis_dicts, redis_root))
+    loop.run_until_complete(run_cache_to_django(
+        redis_root,
+        django_model,
+        redis_dicts,
+    ))
 
 
 async def update_or_create_django_instance_from_redis_instance(
