@@ -134,12 +134,18 @@ class RedisDateTime(RedisString):
 class RedisForeignKey(RedisNumber):
 
     def __init__(self, model=None, save_related_models=False, *args, **kwargs):
-        if not issubclass(model, RedisModel):
+        allowed = True
+        if model is None:
+            allowed = False
+        elif not issubclass(model, RedisModel):
+            allowed = False
+        if not allowed:
             raise Exception(f'{model.__name__} class is not RedisModel')
-        self.model = model
-        check_types(save_related_models, bool)
-        self.save_related_models = save_related_models
-        super().__init__(*args, **kwargs)
+        else:
+            self.model = model
+            check_types(save_related_models, bool)
+            self.save_related_models = save_related_models
+            super().__init__(*args, **kwargs)
 
     def _get_id_from_instance_dict(self):
         if self.value:
@@ -235,12 +241,18 @@ class RedisList(RedisJson):
 class RedisManyToMany(RedisList):
 
     def __init__(self, model=None, save_related_models=False, *args, **kwargs):
-        if not issubclass(model, RedisModel):
+        allowed = True
+        if model is None:
+            allowed = False
+        elif not issubclass(model, RedisModel):
+            allowed = False
+        if not allowed:
             raise Exception(f'{model.__name__} class is not RedisModel')
-        self.model = model
-        check_types(save_related_models, bool)
-        self.save_related_models = save_related_models
-        super().__init__(*args, **kwargs)
+        else:
+            self.model = model
+            check_types(save_related_models, bool)
+            self.save_related_models = save_related_models
+            super().__init__(*args, **kwargs)
 
     def clean(self):
         self.value = self.check_value()
@@ -532,7 +544,7 @@ class RedisRoot:
                         value = real_value
                         allowed_redis_params[redis_field_param_name] = value
                     elif django_field_param_name == 'remote_field':
-                        redis_field_param_name = 'django_model'
+                        redis_field_param_name = 'model'
                         if value is not None:
                             value = value.model
                             if value is not None:
@@ -900,8 +912,7 @@ class RedisRoot:
             redis_model = self.get_or_create_redis_model_from_django_model(django_model)
             return redis_model
         else:
-            raise Exception(f'{django_model} is not registered in redis cache')
-
+            raise Exception(f'Django model {django_model} is not registered in redis cache')
 
     def get(self, django_model, return_dict=False, **filters):
         model = self._django_model_to_redis_model(django_model)
